## Overview

<!-- What does this PR do? Why is it needed? -->

## Type of Change

<!-- Please uncomment the one that applies -->

- [ ] 🐞 Bug fix
- [ ] ✨ New feature
- [ ] 📝 Documentation update
- [ ] ♻️ Refactor
- [ ] ✅ Test addition
- [ ] Other (explain below):

## Changes

<!-- Summarize the main changes clearly -->

- Implemented ...
- Fixed ...
- Refactored ...
- Updated ...

## How to Verify

<!-- Steps to manually verify the changes -->

1. Activate the virtual environment
2. Run the test suite with `pytest`
3. Confirm that all tests pass and no errors occur

Run:

'''
pytest
'''

Make sure all tests pass.

## Screenshots (if applicable)

<!-- Paste screenshots here if UI is affected -->

## Related Issue

<!-- Link related issues (use Closes, Fixes, or See) -->

Closes #123
